/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file freeway.h
 *
 * @type helper
 *
 * @description
 *
 * The freeway helper is an interface to the Freeway module. It
 * is experimental, and has not been properly debugged. Also note
 * that the documentation has come from looking at the source,
 * rather than from anything else, so it may be incorrect.
 */

#ifndef __rov_freeway
#define __rov_freeway


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Register/deregister with Freeway.
 * @param flags the Freeway flags.
 * @param type the Freeway type.
 * @param name the Freeway object name.
 * @param desc_len the object descriptor length.
 * @return non-zero for success.
 * @see Freeway flags
 */
int freeway_register(int flags,
		     int type,
		     char *name,
		     int desc_len);

/**
 * Creates/removes a Freeway object.
 * @param flags the Freeway flags.
 * @param type the Freeway type.
 * @param name the object name.
 * @param desc_len the descriptor length.
 * @param descriptor the pointer to the descriptor.
 * @param auth the authentication.
 * @return non-zero for success.
 * @see Freeway flags
 */
int freeway_write(int flags,
		  int type,
		  char *name,
		  int desc_len,
		  void *descriptor,
		  int auth);

/**
 * Reads a Freeway object.
 * @param flags the Freeway flags.
 * @param type the Freeway type.
 * @param name the object name.
 * @param desc_len the descriptor length.
 * @param descriptor the pointer to the descriptor.
 * @param auth the authentication.
 * @return descriptor length, or -1 for failure.
 * @see Freeway flags
 */
int freeway_read(int flags,
		 int type,
		 char *name,
		 int desc_len,
		 void *descriptor,
		 int auth);

/**
 * @section Freeway flags
 */
#define FREEWAY_ADD		(0<<0)
#define FREEWAY_REMOVE		(1<<0)
#define FREEWAY_REGISTER	(0<<0)
#define FREEWAY_DEREGISTER	(1<<0)
#define FREEWAY_AUTHENTICATE	(1<<1)
#define FREEWAY_UNAUTHENTICATE	(0<<1)
#define FREEWAY_NAMED		(1<<2)
#define FREEWAY_UNNAMED		(0<<2)


#ifdef __cplusplus
}
#endif

#endif
